summary refs log tree commit diff
path: root/pkgs/development/tools/continuous-integration
diff options
context:
space:
mode:
authorBobby Rong <rjl931189261@126.com>2021-12-17 16:01:47 +0800
committerGitHub <noreply@github.com>2021-12-17 16:01:47 +0800
commit4ab7be9a55b02d9c45da7f00a74f76657538e704 (patch)
tree46a88b9c318aaec45f8b8811b7fe45a9ce22db50 /pkgs/development/tools/continuous-integration
parentb4693d8dae675309563e1781938f8e6cb4e15439 (diff)
parentd498380c8847e013f3158e1b5206c58b861426c1 (diff)
downloadnixpkgs-4ab7be9a55b02d9c45da7f00a74f76657538e704.tar
nixpkgs-4ab7be9a55b02d9c45da7f00a74f76657538e704.tar.gz
nixpkgs-4ab7be9a55b02d9c45da7f00a74f76657538e704.tar.bz2
nixpkgs-4ab7be9a55b02d9c45da7f00a74f76657538e704.tar.lz
nixpkgs-4ab7be9a55b02d9c45da7f00a74f76657538e704.tar.xz
nixpkgs-4ab7be9a55b02d9c45da7f00a74f76657538e704.tar.zst
nixpkgs-4ab7be9a55b02d9c45da7f00a74f76657538e704.zip
Merge pull request #148342 from veehaitch/github-runner-v2.285.0
github-runner: 2.284.0 -> 2.285.1
Diffstat (limited to 'pkgs/development/tools/continuous-integration')
-rw-r--r--pkgs/development/tools/continuous-integration/github-runner/default.nix16
1 files changed, 11 insertions, 5 deletions
diff --git a/pkgs/development/tools/continuous-integration/github-runner/default.nix b/pkgs/development/tools/continuous-integration/github-runner/default.nix
index 97312c835f5..17a0cff31fe 100644
--- a/pkgs/development/tools/continuous-integration/github-runner/default.nix
+++ b/pkgs/development/tools/continuous-integration/github-runner/default.nix
@@ -14,6 +14,7 @@
 , lttng-ust
 , makeWrapper
 , nodejs-12_x
+, nodejs-16_x
 , openssl
 , stdenv
 , zlib
@@ -37,13 +38,13 @@ let
 in
 stdenv.mkDerivation rec {
   pname = "github-runner";
-  version = "2.284.0";
+  version = "2.285.1";
 
   src = fetchFromGitHub {
     owner = "actions";
     repo = "runner";
     rev = "v${version}";
-    sha256 = "sha256-JR0OzbT5gGhO/dxb/eSjP/d/VxW/aLmTs/oPwN8b8Rc=";
+    hash = "sha256-SlKUuebsoZ9OgYuDTNOlY1KMg01LFSFazrLCctiFq3A=";
   };
 
   nativeBuildInputs = [
@@ -142,6 +143,9 @@ stdenv.mkDerivation rec {
   disabledTests = [
     # Self-updating is patched out, hence this test will fail
     "FullyQualifiedName!=GitHub.Runner.Common.Tests.Listener.RunnerL0.TestRunOnceHandleUpdateMessage"
+  ] ++ lib.optionals (stdenv.hostPlatform.system == "aarch64-linux") [
+    # "JavaScript Actions in Alpine containers are only supported on x64 Linux runners. Detected Linux Arm64"
+    "FullyQualifiedName!=GitHub.Runner.Common.Tests.Worker.StepHostL0.DetermineNodeRuntimeVersionInAlpineContainerAsync"
   ] ++ map
     # Online tests
     (x: "FullyQualifiedName!=GitHub.Runner.Common.Tests.Worker.ActionManagerL0.PrepareActions_${x}")
@@ -189,6 +193,7 @@ stdenv.mkDerivation rec {
 
     mkdir -p _layout/externals
     ln -s ${nodejs-12_x} _layout/externals/node12
+    ln -s ${nodejs-16_x} _layout/externals/node16
 
     # BUILDCONFIG needs to be "Debug"
     dotnet msbuild \
@@ -230,11 +235,12 @@ stdenv.mkDerivation rec {
       --replace './externals' "$out/externals" \
       --replace './bin' "$out/lib"
 
     # The upstream package includes Node 12 and expects it at the path
     # externals/node12. As opposed to the official releases, we don't
     # link the Alpine Node flavor.
     mkdir -p $out/externals
     ln -s ${nodejs-12_x} $out/externals/node12
+    ln -s ${nodejs-16_x} $out/externals/node16
 
     runHook postInstall
   '';
@@ -230,11 +235,12 @@ stdenv.mkDerivation rec {
       --replace './bin' "$out/lib"
 
-    # The upstream package includes Node 12 and expects it at the path
-    # externals/node12. As opposed to the official releases, we don't
-    # link the Alpine Node flavor.
+    # The upstream package includes Node {12,16} and expects it at the path
+    # externals/node{12,16}. As opposed to the official releases, we don't
+    # link the Alpine Node flavors.
     mkdir -p $out/externals
     ln -s ${nodejs-12_x} $out/externals/node12